@@ -22,12 +22,15 @@
 #include <NetworkManager.h>
 
 #include "ce-ip-address-entry.h"
+#include "ui-helpers.h"
+#include <glib/gi18n.h>
 
 struct _CEIPAddressEntry
 {
   GtkEntry parent_instance;
 
   int family;
+  gulong notify_id;
 };
 
 static void ce_ip_address_entry_editable_init (GtkEditableInterface *iface);
@@ -36,15 +39,40 @@ G_DEFINE_TYPE_WITH_CODE (CEIPAddressEntry, ce_ip_address_entry, GTK_TYPE_ENTRY,
                          G_IMPLEMENT_INTERFACE (GTK_TYPE_EDITABLE,
                                                 ce_ip_address_entry_editable_init))
 
+static void
+ce_ip_address_focus (CEIPAddressEntry *self, GParamSpec *pspec, gpointer data)
+{
+  /* We must check the validity only after the user has entered or exited the widget.
+     We can't do this in `ce_ip_address_entry_is_valid()` because it is called
+     after each keystroke, and the user would receive constantly notifications
+     of "IP address value not valid" until the value is correct.
+  */
+  if (!ce_ip_address_entry_is_valid (self))
+    {
+      gtk_accessible_announce (GTK_ACCESSIBLE (self),
+                               _("IP address value not valid"),
+                               GTK_ACCESSIBLE_ANNOUNCEMENT_PRIORITY_HIGH);
+    }
+}
+
 static void
 ce_ip_address_entry_changed (GtkEditable *editable)
 {
   CEIPAddressEntry *self = CE_IP_ADDRESS_ENTRY (editable);
 
   if (ce_ip_address_entry_is_valid (self))
-    gtk_widget_remove_css_class (GTK_WIDGET (self), "error");
+    widget_unset_error (GTK_WIDGET (self));
   else
-    gtk_widget_add_css_class (GTK_WIDGET (self), "error");
+    widget_set_error (GTK_WIDGET (self));
+}
+
+static void
+ce_ip_address_entry_dispose (GObject *object)
+{
+  CEIPAddressEntry *self = CE_IP_ADDRESS_ENTRY (object);
+  g_clear_signal_handler (&self->notify_id, self);
+
+  G_OBJECT_CLASS (ce_ip_address_entry_parent_class)->dispose (object);
 }
 
 static void
@@ -61,6 +89,8 @@ ce_ip_address_entry_editable_init (GtkEditableInterface *iface)
 static void
 ce_ip_address_entry_class_init (CEIPAddressEntryClass *klass)
 {
+  GObjectClass *object_class = G_OBJECT_CLASS (klass);
+  object_class->dispose = ce_ip_address_entry_dispose;
 }
 
 CEIPAddressEntry *
@@ -70,6 +100,7 @@ ce_ip_address_entry_new (int family)
 
   self = g_object_new (CE_TYPE_IP_ADDRESS_ENTRY, NULL);
   self->family = family;
+  g_signal_connect (self, "notify::has-focus", (GCallback) ce_ip_address_focus, NULL);
 
   return self;
 }
