@@ -23,10 +23,13 @@
 #include <NetworkManager.h>
 
 #include "ce-netmask-entry.h"
+#include "ui-helpers.h"
+#include <glib/gi18n.h>
 
 struct _CENetmaskEntry
 {
   GtkEntry parent_instance;
+  gulong notify_id;
 };
 
 static void ce_netmask_entry_editable_init (GtkEditableInterface *iface);
@@ -65,20 +68,37 @@ parse_netmask (const char *str, guint32 *prefix)
   return FALSE;
 }
 
+static void
+ce_netmask_focus (CENetmaskEntry *self, GParamSpec *pspec, gpointer data)
+{
+  /* We must check the validity only after the user has entered or exited the widget.
+     We can't do this in `ce_netmask_entry_is_valid()` because it is called
+     after each keystroke, and the user would receive constantly notifications
+     of "Netmask value not valid" until the value is correct.
+  */
+  if (!ce_netmask_entry_is_valid (self))
+    {
+      gtk_accessible_announce (GTK_ACCESSIBLE (self),
+                               _("Netmask value not valid"),
+                               GTK_ACCESSIBLE_ANNOUNCEMENT_PRIORITY_HIGH);
+    }
+}
+
 static void
 ce_netmask_entry_changed (GtkEditable *editable)
 {
   CENetmaskEntry *self = CE_NETMASK_ENTRY (editable);
 
   if (ce_netmask_entry_is_valid (self))
-    gtk_widget_remove_css_class (GTK_WIDGET (self), "error");
+    widget_unset_error (GTK_WIDGET (self));
   else
-    gtk_widget_add_css_class (GTK_WIDGET (self), "error");
+    widget_set_error (GTK_WIDGET (self));
 }
 
 static void
 ce_netmask_entry_init (CENetmaskEntry *self)
 {
+  g_signal_connect (self, "notify::has-focus", (GCallback) ce_netmask_focus, NULL);
 }
 
 static void
@@ -87,9 +107,24 @@ ce_netmask_entry_editable_init (GtkEditableInterface *iface)
   iface->changed = ce_netmask_entry_changed;
 }
 
+static void
+ce_netmask_entry_dispose (GObject *object)
+{
+  CENetmaskEntry *self = CE_NETMASK_ENTRY (object);
+  if (self->notify_id)
+    {
+      g_signal_handler_disconnect (self, self->notify_id);
+      self->notify_id = 0;
+    }
+
+  G_OBJECT_CLASS (ce_netmask_entry_parent_class)->dispose (object);
+}
+
 static void
 ce_netmask_entry_class_init (CENetmaskEntryClass *klass)
 {
+  GObjectClass *object_class = G_OBJECT_CLASS (klass);
+  object_class->dispose = ce_netmask_entry_dispose;
 }
 
 CENetmaskEntry *
