@@ -18,21 +18,34 @@
  */
 
 #include "config.h"
-
 #include "ui-helpers.h"
 
 void
 widget_set_error (GtkWidget *widget)
 {
-	g_return_if_fail (GTK_IS_WIDGET (widget));
+  g_return_if_fail (GTK_IS_WIDGET (widget));
 
-	gtk_widget_add_css_class (widget, "error");
+  gtk_widget_add_css_class (widget, "error");
+  gtk_accessible_update_state (GTK_ACCESSIBLE (widget),
+                               GTK_ACCESSIBLE_STATE_INVALID,
+                               GTK_ACCESSIBLE_INVALID_TRUE,
+                               -1);
+  if (GTK_IS_ENTRY (widget))
+    gtk_entry_set_icon_from_icon_name (GTK_ENTRY (widget),
+                                       GTK_ENTRY_ICON_SECONDARY,
+                                       "dialog-error-symbolic");
 }
 
 void
 widget_unset_error (GtkWidget *widget)
 {
-	g_return_if_fail (GTK_IS_WIDGET (widget));
+  g_return_if_fail (GTK_IS_WIDGET (widget));
 
-	gtk_widget_remove_css_class (widget, "error");
+  gtk_widget_remove_css_class (widget, "error");
+  gtk_accessible_reset_state (GTK_ACCESSIBLE (widget),
+                              GTK_ACCESSIBLE_STATE_INVALID);
+  if (GTK_IS_ENTRY (widget))
+    gtk_entry_set_icon_from_icon_name (GTK_ENTRY (widget),
+                                       GTK_ENTRY_ICON_SECONDARY,
+                                       NULL);
 }
