@@ -285,7 +285,8 @@ cc_battery_row_new (UpDevice *device,
   /* Percentage label */
   if (battery_level == UP_DEVICE_LEVEL_NONE)
   {
-    s = g_strdup_printf ("%d%%", (int)percentage);
+    /* TRANSLATORS: This is the battery charge level percentage (e.g. 50%). This could be localized to account for local Percent sign formatting guidelines. See https://en.wikipedia.org/wiki/Percent_sign#Correct_style */
+    s = g_strdup_printf (_("%d %%"), (int)percentage);
     gtk_label_set_text (self->percentage_label, s);
     gtk_label_set_text (self->primary_percentage_label, s);
   }
@@ -316,34 +317,6 @@ cc_battery_row_new (UpDevice *device,
 
 
 
-void
-cc_battery_row_set_level_sizegroup (CcBatteryRow *self,
-                                    GtkSizeGroup *sizegroup)
-{
-  gtk_size_group_add_widget (sizegroup, GTK_WIDGET (self->levelbar));
-}
-
-void
-cc_battery_row_set_row_sizegroup (CcBatteryRow *self,
-                                  GtkSizeGroup *sizegroup)
-{
-  gtk_size_group_add_widget (sizegroup, GTK_WIDGET (self));
-}
-
-void
-cc_battery_row_set_charge_sizegroup (CcBatteryRow *self,
-                                     GtkSizeGroup *sizegroup)
-{
-  gtk_size_group_add_widget (sizegroup, GTK_WIDGET (self->percentage_label));
-}
-
-void
-cc_battery_row_set_battery_sizegroup (CcBatteryRow *self,
-                                      GtkSizeGroup *sizegroup)
-{
-  gtk_size_group_add_widget (sizegroup, GTK_WIDGET (self->battery_box));
-}
-
 gboolean
 cc_battery_row_get_primary (CcBatteryRow *self)
 {
