@@ -27,10 +27,10 @@ G_BEGIN_DECLS
 #define CC_TYPE_SUBWOOFER_SLIDER (cc_subwoofer_slider_get_type ())
 G_DECLARE_FINAL_TYPE (CcSubwooferSlider, cc_subwoofer_slider, CC, SUBWOOFER_SLIDER, GtkWidget)
 
-void cc_subwoofer_slider_set_mixer_control (CcSubwooferSlider *slider,
+void cc_subwoofer_slider_set_mixer_control (CcSubwooferSlider *self,
                                             GvcMixerControl   *mixer_control);
 
-void cc_subwoofer_slider_set_channel_map   (CcSubwooferSlider *slider,
+void cc_subwoofer_slider_set_channel_map   (CcSubwooferSlider *self,
                                             GvcChannelMap     *channel_map);
 
 G_END_DECLS
