@@ -548,12 +548,6 @@ on_permission_changed (CcDateTimePage *self)
   gtk_widget_set_sensitive (GTK_WIDGET (self->auto_timezone_row), location_allowed && (allowed || tz_allowed));
   gtk_widget_set_sensitive (GTK_WIDGET (self->datetime_row), allowed && !using_ntp);
   gtk_widget_set_sensitive (GTK_WIDGET (self->timezone_row), (allowed || tz_allowed) && (!auto_timezone || !location_allowed));
-
-  /* Hide the subdialogs if we no longer have permissions */
-  if (!allowed)
-      gtk_widget_set_visible (GTK_WIDGET (self->datetime_dialog), FALSE);
-  if (!allowed && !tz_allowed)
-      gtk_widget_set_visible (GTK_WIDGET (self->timezone_dialog), FALSE);
 }
 
 static void
@@ -816,7 +810,6 @@ cc_date_time_page_class_init (CcDateTimePageClass *klass)
 
   gtk_widget_class_bind_template_child (widget_class, CcDateTimePage, auto_datetime_row);
   gtk_widget_class_bind_template_child (widget_class, CcDateTimePage, auto_timezone_row);
-  gtk_widget_class_bind_template_child (widget_class, CcDateTimePage, auto_timezone_row);
   gtk_widget_class_bind_template_child (widget_class, CcDateTimePage, date_box);
   gtk_widget_class_bind_template_child (widget_class, CcDateTimePage, datetime_row);
   gtk_widget_class_bind_template_child (widget_class, CcDateTimePage, datetime_dialog);
