@@ -38,7 +38,7 @@ typedef struct
 	gdouble y_max;
 } XYinfo;
 
-#define CC_TYPE_CALIB_AREA cc_calib_area_get_type ()
+#define CC_TYPE_CALIB_AREA (cc_calib_area_get_type ())
 G_DECLARE_FINAL_TYPE (CcCalibArea, cc_calib_area, CC, CALIB_AREA, GtkWindow)
 
 typedef void (*FinishCallback) (CcCalibArea *area, gpointer user_data);
